/*
	$Id: CommonItemTransfer.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2005, 2006 Jari Häkkinen, Gregory Vincic
	Copyright (C) 2007 Jari Häkkinen, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or
	(at your option) any later version.

	BASE is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
	General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/

package net.sf.basedb.clients.migrate;

import net.sf.basedb.core.CommonItem;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.SharedItem;
import java.sql.ResultSet;

/**
Common items have a specific set of columns in Base 1. The columns must be in
the following order <br/> id, owner, gid, groupAccess, worldAccess, name,
descr, removed <br/> This class provides methods to set these values on new
CommonItems in BASE 2.

@author Gregory Vincic
@version 2.0
@base.modified $Date: 2009-04-06 14:52:39 +0200 (Mon, 06 Apr 2009) $
*/

abstract class CommonItemTransfer extends SharedItemTransfer
{
	/**
	Column index in the ResultSet
	 */
	protected final int NAME = 6;
	/**
	Column index in the ResultSet
	 */
	protected final int DESCRIPTION = 7;
	/**
	Column index in the ResultSet
	 */
	protected final int REMOVED = 8;

	/**
	Logger for this class
	 */
	private static final org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger("net.sf.basedb.clients.migrate.CommonItemTransfer");
	
	CommonItemTransfer()
	{}
	
	CommonItemTransfer(UserTransfer userT, GroupTransfer groupT)
	{
		super(userT, groupT);
	}

	/**
	@param item <code>CommonItem</code>
	@param rs <code>ResultSet</code> IMPORTANT that the select statement
	       for this ResultSet begins with "SELECT id, owner, gid,
	       groupAccess, worldAccess, name, descr, removed,... "
	 */
	protected void setCommonItemData(DbControl dbc, CommonItem item,
			ResultSet rs)
	{		
		setSharedItemData(dbc, (SharedItem) item, rs);
		log.debug("setting CommonItemData");
		try
		{
			String name = rs.getString(NAME);
			// Empty names are not valid in BASE 2
			if (name == null || name.equals(""))
				item.setName("No name");
			else
				item.setName(name);
			String description = rs.getString(DESCRIPTION);
			if (description == null)
				item.setDescription("");
			else
				item.setDescription(description);
			item.setRemoved(rs.getBoolean(REMOVED));
		}
		catch (Exception e)
		{
			log.error("FAILED setting CommonItemData on item: " + item);
			stop();
		}
	}
}
