/*
  $Id: FileSetMemberData.java 5063 2009-08-19 11:31:03Z nicklas $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

  BASE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 3
  of the License, or (at your option) any later version.

  BASE is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

/**
	This class hols information about individual files attached
	to items that store data in files instead of in the
	database.
	
	@author Nicklas
	@version 2.5
	@see net.sf.basedb.core.FileSetMember
	@see <a href="../../../../../../html/developerdoc/api/data_api.platforms.html">Data API - Experimental platforms</a>
	@base.modified $Date: 2009-08-19 13:31:03 +0200 (Wed, 19 Aug 2009) $
	@hibernate.class table="`FileSetMembers`" lazy="true"
*/
public class FileSetMemberData
	extends BasicData
	implements LoggableData
{

	private FileSetData fileSet;
	/**
		Get the file set this file belongs to.
		@hibernate.many-to-one outer-join="false" update="false"
		@hibernate.column name="`fileset_id`" not-null="true" unique-key="uniquetype"
	*/
	public FileSetData getFileSet()
	{
		return fileSet;
	}
	public void setFileSet(FileSetData fileSet)
	{
		this.fileSet = fileSet;
	}
	
	private DataFileTypeData fileType;
	/**
		Get the type of this file. A set may only contain one file for each type.
		@hibernate.many-to-one outer-join="false" update="false"
		@hibernate.column name="`datafiletype_id`" not-null="true" unique-key="uniquetype"
	*/
	public DataFileTypeData getDataFileType()
	{
		return fileType;
	}
	public void setDataFileType(DataFileTypeData fileType)
	{
		this.fileType = fileType;
	}
	
	private FileData file;
	/**
		Get the file.
		@hibernate.many-to-one outer-join="false"
		@hibernate.column name="`file_id`" not-null="true"
	*/
	public FileData getFile()
	{
		return file;
	}
	public void setFile(FileData file)
	{
		this.file = file;
	}
	
	private Boolean valid;
	/**
		If the file has been validated or not. A null value indicates that
		the file hasn't been validated. A FALSE value indicates an invalid
		file.
		@hibernate.property column="`valid`" type="boolean" not-null="false"
	*/
	public Boolean isValid()
	{
		return valid;
	}
	public void setValid(Boolean valid)
	{
		this.valid = valid;
	}

	private String errorMessage;
	/**
		The error message if the file validation failed.
		@hibernate.property column="`error_message`" type="text"
	*/
	public String getErrorMessage()
	{
		return errorMessage;
	}
	public void setErrorMessage(String errorMessage)
	{
		this.errorMessage = errorMessage;
	}

}
