/*
  $Id: HelpData.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2005 Johan Enell, Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

  BASE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 3
  of the License, or (at your option) any later version.

  BASE is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

/**
	This class holds information about an help item.
	
	@author enell
	@version 2.0
	@see net.sf.basedb.core.Help
	@see <a href="../../../../../../html/developerdoc/api/data_api.clients.html">Session and client overview</a>
	@base.modified $Date: 2009-04-06 14:52:39 +0200 (Mon, 06 Apr 2009) $
	@hibernate.class table="`HelpTexts`" lazy="false"
 */
public class HelpData
	extends BasicData
	implements NameableData
{
	public HelpData()
	{}

	/*
		From the NameableData interface
		-------------------------------------------
	*/	
	private String name;
	public String getName()
	{
		return name;
	}

	public void setName(String name)
	{
		this.name = name;
	}

	private String description;
	public String getDescription()
	{
		return description;
	}

	public void setDescription(String description)
	{
		this.description = description;
	}
	// -------------------------------------------

	private ClientData client;
	/**
		Get the client for this help text.
		@hibernate.many-to-one outer-join="false" update="false"
		@hibernate.column name="`client_id`" not-null="true" unique-key="uniquehelp"
	*/
	public ClientData getClient()
	{
		return client;
	}
	public void setClient(ClientData client)
	{
		this.client = client;
	}

	/**
		The maximum length of the external ID that can be stored in the database.
		@see #setExternalId(String)
	*/
	public static final int MAX_EXTERNAL_ID_LENGTH = 255;
	private String externalId;
	/**
		Get the external id for this <code>Help</code> item.
		@hibernate.property type="string"
		@hibernate.column name="`external_id`" length="255" not-null="true" unique-key="uniquehelp"
	*/
	public String getExternalId()
	{
		return externalId;
	}
	public void setExternalId(String externalId)
	{
		this.externalId = externalId;
	}

}
