/*
  $Id: ProtocolData.java 5248 2010-02-17 12:10:13Z nicklas $

	Copyright (C) 2005 Johan Enell, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

  BASE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 3
  of the License, or (at your option) any later version.

  BASE is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Date;
import java.util.HashSet;
import java.util.Set;

/**
	@author enell
	@version 2.0
	@see net.sf.basedb.core.Protocol
	@see <a href="../../../../../../html/developerdoc/api/data_api.protocols.html">Protocol overview</a>
	@hibernate.class table="`Protocols`" lazy="true"
*/
public class ProtocolData
	extends AnnotatedData
	implements FileAttachableData, RegisteredData
{

	public ProtocolData()
	{}
	
	/*
		From the FileAttachableData interface
		-------------------------------------------
	*/
	private FileData file;
	public FileData getFile()
	{
		return file;
	}

	public void setFile(FileData file)
	{
		this.file = file;
	}
	// -------------------------------------------
	/*
		From the RegisteredData interface
		-------------------------------------------
	*/
	private Date entryDate;
	public Date getEntryDate()
	{
		return entryDate;
	}
	public void setEntryDate(Date entryDate)
	{
		this.entryDate = entryDate;
	}
	// -------------------------------------------

	private ProtocolTypeData protocolType;
	/**
		Get the associated {@link ProtocolTypeData} item.
		@hibernate.many-to-one column="`protocoltype_id`" not-null="true" outer-join="false"
	*/
	public ProtocolTypeData getProtocolType()
	{
		return protocolType;
	}
	public void setProtocolType(ProtocolTypeData protocolType)
	{
		this.protocolType = protocolType;
	}
	
	/**
		The maximum length of the external id that can be stored in the database.
		@see #setExternalId(String)
		@since 2.15
	*/
	public static final int MAX_EXTERNAL_ID_LENGTH = 255;
	private String externalId;
	/**
		Get the external id for the protocol.
		@hibernate.property column="`external_id`" type="string" length="255" not-null="false"
		@since 2.15
	*/
	public String getExternalId()
	{
		return externalId;
	}
	public void setExternalId(String externalId)
	{
		this.externalId = externalId;
	}

	
	private Set<AnnotationTypeData> parameters;
	/**
		This set manages the parameters for this protcol.
		@hibernate.set table="`ProtocolParameters`" lazy="true"
		@hibernate.collection-key column="`protocol_id`"
		@hibernate.collection-many-to-many column="`annotationtype_id`" 
			class="net.sf.basedb.core.data.AnnotationTypeData"
		@since 2.2
	*/
	public Set<AnnotationTypeData> getParameters()
	{
		if (parameters == null) parameters = new HashSet<AnnotationTypeData>();
		return parameters;
	}
	void setParameters(Set<AnnotationTypeData> parameters)
	{
		this.parameters = parameters;
	}
	
	
}
