/**
	$Id: DbLogManager.java 5038 2009-08-07 10:50:01Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.log.db;

import net.sf.basedb.core.LogControl;
import net.sf.basedb.core.data.ChangeHistoryData;
import net.sf.basedb.core.data.ChangeHistoryDetailData;
import net.sf.basedb.core.log.LogManager;

/**
	Log manager implementation that logs changes to the database.

	@author Nicklas
	@version 2.13
	@base.modified $Date: 2009-08-07 12:50:01 +0200 (Fri, 07 Aug 2009) $
*/
public class DbLogManager
	implements LogManager
{
	
	private final LogControl logControl;
	private ChangeHistoryData history;
	

	public DbLogManager(LogControl logControl)
	{
		this.logControl = logControl;
	}

	/*
		From the LogManager interface
		-----------------------------
	*/
	@Override
	public void afterCommit()
	{}

	@Override
	public void afterRollback()
	{}
	@Override
	public LogControl getLogControl()
	{
		return logControl;
	}
	// ------------------------------
	
	/**
		Log the given details to the database. The
		{@link ChangeHistoryDetailData#setChangeHistory(ChangeHistoryData)}
		is automatically populated (and saved if needed) with information
		from the current transaction.
	*/
	public void logChangeDetails(ChangeHistoryDetailData details)
	{
		if (history == null) createHistory();
		details.setChangeHistory(history);
		logControl.log(details);
	}
	
	private void createHistory()
	{
		history = logControl.getTransactionDetails().toChangeHistoryData();
		logControl.log(history);
	}
	
}
