/**
	$Id: DefaultEntityLogger.java 5052 2009-08-18 06:47:26Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.log.db;

import net.sf.basedb.core.data.ChangeHistoryDetailData;
import net.sf.basedb.core.data.LoggableData;
import net.sf.basedb.core.log.EntityDetails;
import net.sf.basedb.core.log.EntityLogger;
import net.sf.basedb.core.log.LogManager;

/**
	Default logger for all entities that has been tagged with the
	{@link LoggableData} interface.

	@author Nicklas
	@version 2.13
	@base.modified $Date: 2009-08-18 08:47:26 +0200 (Tue, 18 Aug 2009) $
*/
public class DefaultEntityLogger
	implements EntityLogger
{

	private final boolean detailedProperties;
	
	/**
		Creates a new entity logger.
		@param detailedProperties If TRUE, the log includes a list with
			the properties that was modified
	*/
	public DefaultEntityLogger(boolean detailedProperties)
	{
		this.detailedProperties = detailedProperties;
	}
	
	/*
		From the EntityLogger interface
		-------------------------------
	*/
	/**
		Creates a new {@link ChangeHistoryDetailData} and saves it to
		{@link DbLogManager#logChangeDetails(ChangeHistoryDetailData)}.
	*/
	@Override
	public void logChanges(LogManager logManager, EntityDetails details)
	{
		DbLogManager dbLogManager = (DbLogManager)logManager;
		ChangeHistoryDetailData change = details.toChangeHistoryDetailData(detailedProperties);
		dbLogManager.logChangeDetails(change);
	}
	// -------------------------------
}
