/**
	$Id: ActionClassEventFilter.java 4515 2008-09-11 20:08:14Z jari $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions.events;

import net.sf.basedb.util.extensions.Action;
import net.sf.basedb.util.extensions.Extension;
import net.sf.basedb.util.extensions.ExtensionPoint;

/**
	Event filter that only passes on events to extension points with a
	given action class.

	@author nicklas
	@version 2.8
	@base.modified $Date: 2008-09-11 22:08:14 +0200 (Thu, 11 Sep 2008) $
 */
public class ActionClassEventFilter
	implements EventFilter
{

	private final Class<? extends Action> clazz;
	/**
		Create a new action class filter. This filter will pass events
		for extension points where the class returned by 
		{@link ExtensionPoint#getActionClass()} is the same class or a subclass
		to the class given in this constructor.
		@param clazz The class
	*/
	public ActionClassEventFilter(Class<? extends Action> clazz)
	{
		this.clazz = clazz;
	}
	
	/**
		@return TRUE if the {@link ExtensionPoint#getActionClass()} is the
			same class or a subclass of the class given in the constructor
	 */
	@Override
	public boolean shouldSend(EventType event, ExtensionPoint<?> extensionPoint,
			Extension<?> extension)
	{
		return clazz.isAssignableFrom(extensionPoint.getActionClass());
	}

}
