/**
	$Id: BioSourceLoader.java 4740 2009-02-05 13:39:25Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.loader;

import net.sf.basedb.core.BioSource;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.PermissionDeniedException;
import net.sf.basedb.core.Sample;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.node.ChildNodeDirection;
import net.sf.basedb.util.overview.node.NameableNameGenerator;
import net.sf.basedb.util.overview.Node;
import net.sf.basedb.util.overview.node.NodeFactory;

/**
	Node loader implementation for biosources. Biosources are
	an endpoint node with the forward-loading direction going to 
	{@link BioSource}:s -&gt; {@link Sample}:s.

	@author Nicklas
	@version 2.10
	@base.modified $Date: 2009-02-05 14:39:25 +0100 (Thu, 05 Feb 2009) $
*/
public class BioSourceLoader
	extends BasicItemNodeLoader<BioSource>
{

	public BioSourceLoader()
	{
		super(Item.BIOSOURCE, ALLOW_ROOT_NODE, new NameableNameGenerator<BioSource>("biosource", "Biosource"));
	}
	
	/*
		From the NodeLoader interface
		------------------------------
	*/
	/**
		Create a reverse-loading biosource node from a sample node.
		@return A biosource node, which can be null if validation fails
	*/
	@Override
	public Node createReverseNode(DbControl dc, OverviewContext context, Node sampleNode)
	{
		NodeFactory<BioSource> nf = getNodeFactory(dc, context);
		BioSource bioSource = null;
		boolean denied = false;
		try
		{
			Sample sample = (Sample)sampleNode.getItem(dc);
			bioSource = sample.getBioSource();
		}
		catch (PermissionDeniedException ex)
		{
			denied = true;
		}
		Node bioSourceNode = createItemNode(nf, bioSource, bioSource, denied, 
				sampleNode, ChildNodeDirection.REVERSE);
		return bioSourceNode;
	}
	// --------------------------------
	/*
		From the AbstractNodeLoader class
		----------------------------------
	*/
	/**
		Loads property nodes of an array design. 
		<ul>
		<li>Annotations: {@link AnnotationLoader#createPropertyNode(DbControl, OverviewContext, Node)}
		</ul>
	*/
	@Override
	protected void loadPropertyChildNodes(DbControl dc, OverviewContext context, Node bioSourceNode)
	{
		getNodeLoader(context, Item.ANNOTATION).createPropertyNode(dc, context, bioSourceNode);
	}

	/**
		Loads the sample nodes that has been created from the given biosource node.
		@see ArrayBatchLoader#createForwardNode(DbControl, OverviewContext, Node)
	*/
	@Override
	protected void loadForwardChildNodes(DbControl dc, OverviewContext context, Node bioSourceNode)
	{
		getNodeLoader(context, Item.SAMPLE).createForwardNode(dc, context, bioSourceNode);
	}
	// ---------------------------------------
	
}
