/**
	$Id: LabeledExtractNameGenerator.java 5384 2010-08-13 08:50:27Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.node;

import net.sf.basedb.core.Label;
import net.sf.basedb.core.LabeledExtract;
import net.sf.basedb.util.overview.Node;

/**
	Name generator implementation for {@link LabeledExtract}
	items. The implementation use the {@link NameableNameGenerator}
	but prefixes the node title with the name of the label. Eg.
	<code>cy3: My labeled extract</code>.
	
	@author Nicklas
	@version 2.10
	@base.modified $Date: 2010-08-13 10:50:27 +0200 (Fri, 13 Aug 2010) $
*/
public class LabeledExtractNameGenerator
	extends NameableNameGenerator<LabeledExtract>
{

	/**
		Create a new name generator.
		@param namePrefix The prefix to use in node names
		@param titlePrefix The prefix to use in node titles
	*/
	public LabeledExtractNameGenerator(String namePrefix, String titlePrefix)
	{
		super(namePrefix, titlePrefix);
	}
	
	/*
		From the NameableNameGenerator class
		------------------------------------
	*/
	/**
		The base of the title is generated by the superclass. This
		implementation just prefixes the title with the name of the label.
	*/
	@Override
	public String getNodeTitle(LabeledExtract item, Node parentNode)
	{
		String title = super.getNodeTitle(item, parentNode);
		try
		{
			Label label = item.getLabel();
			title = label.getName() + ": " + title;
		}
		catch (RuntimeException ex)
		{}
		return title;
	}

}
