/**
	$Id: ExtractValidator.java 4764 2009-02-16 19:29:47Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.validator;

import net.sf.basedb.core.BasicItem;
import net.sf.basedb.core.Extract;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.LabeledExtract;
import net.sf.basedb.util.overview.Fix;
import net.sf.basedb.util.overview.Validator;
import net.sf.basedb.util.overview.Node;

/**
	Validator implementation for extracts. Validation rules:
	<ul>
	<li>Missing item: {@link Validator#MISSING_EXTRACT}
	<li>Access denied: {@link Validator#DENIED_EXTRACT}
	</ul>

	@author Nicklas
	@version 2.10
	@base.modified $Date: 2009-02-16 20:29:47 +0100 (Mon, 16 Feb 2009) $
*/
public class ExtractValidator
	extends NameableNodeValidator<Extract>
{
	
	public ExtractValidator()
	{
		super(Validator.MISSING_EXTRACT, Validator.DENIED_EXTRACT);
	}
	
	/* 
		From BasicValidator class
		-------------------------
	*/
	/**
		The suggested fix is to add a parent extract to the 
		labled extract or one or more extracts to the pooled extract.
	*/
	@Override
	protected Fix getMissingItemFix(Node parentNode)
	{
		Fix fix = null;
		Item parentType = parentNode.getItemType();
		BasicItem parentItem = parentNode.getItem();
		if (parentType == Item.LABELEDEXTRACT)
		{
			fix =  new Fix("Add parent extract to '" + ((LabeledExtract)parentItem).getName() + "'", parentItem);
		}
		else if (parentType == Item.EXTRACT)
		{
			fix = new Fix("Add parent extracts to '" + ((Extract)parentItem).getName() + "'", parentItem);
		}
		return fix;
	}
	// ----------------------------
}
