/**
	$Id: HybridizationValidator.java 4764 2009-02-16 19:29:47Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.validator;

import net.sf.basedb.core.Hybridization;
import net.sf.basedb.core.Item;
import net.sf.basedb.util.overview.Fix;
import net.sf.basedb.util.overview.Validator;
import net.sf.basedb.util.overview.Node;

/**
	Validator implementation for hybridizations. Validation rules:
	<ul>
	<li>Missing item: {@link Validator#MISSING_HYBRIDIZATION}
	<li>Access denied: {@link Validator#DENIED_HYBRIDIZATION}
	</ul>

	@author Nicklas
	@version 2.10
	@base.modified $Date: 2009-02-16 20:29:47 +0100 (Mon, 16 Feb 2009) $
*/
public class HybridizationValidator
	extends NameableNodeValidator<Hybridization>
{
	
	public HybridizationValidator()
	{
		super(Validator.MISSING_HYBRIDIZATION, Validator.DENIED_HYBRIDIZATION);
	}

	/* 
		From BasicValidator class
		-------------------------
	*/
	/**
		@return Suggested fix is to add a scan to the parent raw bioassay.
	*/
	@Override
	protected Fix getMissingItemFix(Node parentNode)
	{
		Fix fix = null;
		if (parentNode.getItemType() == Item.SCAN)
		{
			fix = new Fix("Add hybridization to scan", parentNode.getItem());
		}
		return fix;
	}
	// ----------------------------

}
