/**
	$Id: NullNodeValidator.java 4740 2009-02-05 13:39:25Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.validator;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.Node;

/**
	A node validator implementation that accepts all nodes,
	except missing items and denied access items. No validation
	failures are reported.

	@author Nicklas
	@version 2.10
	@base.modified $Date: 2009-02-05 14:39:25 +0100 (Thu, 05 Feb 2009) $
*/
public class NullNodeValidator<I>
	implements NodeValidator<I>
{

	public NullNodeValidator()
	{}

	/*
		From the NodeValidator interface
		--------------------------------
	*/
	/**
		@return Always false
	*/
	@Override
	public boolean preDeniedItem(DbControl dc, OverviewContext context, Node parentNode)
	{
		return false;
	}

	/**
		@return Always false
	*/
	@Override
	public boolean preMissingItem(DbControl dc, OverviewContext context, Node parentNode)
	{
		return false;
	}

	/**
		@return Always true
	*/
	@Override
	public boolean preValidate(DbControl dc, OverviewContext context, I item, Node parentNode)
	{
		return true;
	}
	
	/**
		Do nothing.
	*/
	@Override
	public void postMissingItem(DbControl dc, OverviewContext context, Node node, Node parentNode)
	{}
	
	/**
		Do nothing.
	*/
	@Override
	public void postDeniedItem(DbControl dc, OverviewContext context, Node node, Node parentNode)
	{}
	
	/**
		Do nothing.
	*/
	@Override
	public void postValidate(DbControl dc, OverviewContext context, Node node, Node parentNode)
	{}
	
	/**
		Do nothing.
	*/
	@Override
	public void postValidateFolder(DbControl dc, OverviewContext context, Node folderNode, Node parentNode)
	{}
	// -------------------------------------

}
