/*
	$Id: Base1TestPlugin.java 4720 2009-01-08 10:01:27Z nicklas $
	
	Copyright (C) Nicklas Nordborg
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/
	
	BASE is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or
	(at your option) any later version.
	
	BASE is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.regex.Pattern;

import net.sf.basedb.core.Config;
import net.sf.basedb.util.Values;
import net.sf.basedb.util.parser.FlatFileParser;



public class Base1TestPlugin
{

	/**
	 * @param args
	 * @throws IOException 
	 */
	public static void main(String[] args) throws IOException
	{

		FlatFileParser ffp = getInitializedFlatFileParser(System.in);
		System.out.println("BASEFile");

		boolean mergeAssays = false;
		boolean offsetPositions = false;
		boolean reporterList = false;
		boolean createSubdir = false;
		int numSpotSections = 0;
		while (ffp.hasMoreSections())
		{
			FlatFileParser.Line section = ffp.nextSection();
			ffp.parseHeaders();
			
			//System.out.println("section:::" + section.name());
			if ("settings".equals(section.name()))
			{
				mergeAssays = Values.getBoolean(ffp.getHeader("mergeAssays"));
				offsetPositions = Values.getBoolean(ffp.getHeader("offsetPositions"));
				reporterList = Values.getBoolean(ffp.getHeader("reporterList"));
				createSubdir = Values.getBoolean(ffp.getHeader("createSubdir"));
				//System.out.println("merge: " + mergeAssays + "; offset: " + offsetPositions);
				//System.out.println("createSubdir: " + createSubdir);
			}
			else if ("assays".equals(section.name()) && !reporterList)
			{
				System.out.println("section assays");
				if (mergeAssays)
				{
					System.out.println("count\t1");
					System.out.println("columns\tid\tname\tparents");
					System.out.println("%");
					List<String> parents = new ArrayList<String>();
					while (ffp.hasMoreData())
					{
						FlatFileParser.Data data = ffp.nextData();
						parents.add(data.get(0));
					}
					System.out.println("1\tA merged assay\t" + Values.getString(parents, "/", true));
					System.out.println();
				}
				else
				{
					// Just copy all headers...
					for (FlatFileParser.Line line : ffp.getLines())
					{
						if (line.type() == FlatFileParser.LineType.HEADER)
						{
							System.out.println(line.line());
						}
					}
					System.out.println("%");
					// ...and the data
					while (ffp.hasMoreData())
					{
						FlatFileParser.Data data = ffp.nextData();
						System.out.println(data.line());
					}
					System.out.println();
				}
			}
			else if ("spots".equals(section.name()))
			{
				numSpotSections++;
				
				if (reporterList)
				{
					if (numSpotSections == 1)
					{
						System.out.println("section\treporterlist");
						System.out.println("name\tA reporter list");
						System.out.println("columns\treporterId\tscore");
						System.out.println("%");
						while (ffp.hasMoreData())
						{
							FlatFileParser.Data data = ffp.nextData();
							System.out.println(data.get(2) + "\t" + Math.random());
						}
					}
				}
				else if (!mergeAssays || numSpotSections == 1)
				{
					System.out.println("section\tspots");
					System.out.println("channels\t" + ffp.getHeader("channels"));
					System.out.println("assayFields\t" + ffp.getHeader("assayFields"));
					System.out.println("columns\t" + ffp.getHeader("columns"));
					System.out.println("count\t" + ffp.getHeader("count"));
					System.out.println("assays\t" + (mergeAssays ? "1" : ffp.getHeader("assays")));
					System.out.println("%");
					String offset = offsetPositions ? "1000" : "";
					while (ffp.hasMoreData())
					{
						FlatFileParser.Data data = ffp.nextData();
						System.out.println(offset + data.line().replaceFirst("\\t\\t", "\t0\t"));
					}
					System.out.println();
				}
			}	
		}
		if (createSubdir)
		{
			File tmpDir = new File(System.getProperty("java.io.tmpdir"));
			File subdir = new File(tmpDir, "subdir");
			//System.out.println("Creating subdir: " + subdir + "(" + subdir.getAbsolutePath() + ")");
			subdir.mkdirs();
			File subFile = new File(subdir, "file.txt");
			//System.out.println("Creating file: " + subFile + "(" + subFile.getAbsolutePath() + ")");
			subFile.createNewFile();
		}
	}
	
	private static FlatFileParser getInitializedFlatFileParser(InputStream stream)
	{
		FlatFileParser ffp = new FlatFileParser();
		ffp.setSectionRegexp(Pattern.compile("section[\\t ](.*)"));
		ffp.setHeaderRegexp(Pattern.compile("(.*?)\\t(.*)"));
		ffp.setDataHeaderRegexp(Pattern.compile("%"));
		ffp.setDataFooterRegexp(Pattern.compile("^$"));
		ffp.setDataSplitterRegexp(Pattern.compile("\\t"));
		ffp.setUseNullIfEmpty(false);
		ffp.setInputStream(stream, Config.getCharset());
		return ffp;
	}
	
	

}
