/*
	$Id: TestNumberFormat.java 5460 2010-10-29 12:20:14Z nicklas $

	BioArray Software Environment (BASE) - http://base.thep.lu.se/
	Copyright (C) 2007 Johan Enell, Nicklas Nordborg

	This file is part of BASE.

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
import net.sf.basedb.core.Type;
import net.sf.basedb.util.NumberFormatUtil;

public class TestNumberFormat
{

	static boolean ok = true;
	public static void main(String[] args)
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		ok = test_all();
		TestUtil.stop();
	}

	static boolean test_all()
	{
		write("++Testing Number parser");

		java.text.NumberFormat dotFormat = NumberFormatUtil.getNumberFormat('.', ';');
		float resultPositive = 123.456f;
		float resultNegative = -123.456f;
		
		// Positive numbers
		final boolean SHOULD_FAIL = true;
		final boolean SHOULD_PASS = false;
		test_parse_number(dotFormat, "123.456", resultPositive, SHOULD_PASS);
		test_parse_number(dotFormat, "1.23456E2", resultPositive, SHOULD_PASS);
		test_parse_number(dotFormat, "1.23456E+2", resultPositive, SHOULD_PASS);
		test_parse_number(dotFormat, "1234.56E-1", resultPositive, SHOULD_PASS);
		test_parse_number(dotFormat, "1.23456e2", resultPositive, SHOULD_PASS);
		test_parse_number(dotFormat, "1.23456e+2", resultPositive, SHOULD_PASS);
		test_parse_number(dotFormat, "1234.56e-1", resultPositive, SHOULD_PASS);
		test_parse_number(dotFormat, "123.456E0", resultPositive, SHOULD_PASS);
		test_parse_number(dotFormat, "123.456E+0", resultPositive, SHOULD_PASS);
		test_parse_number(dotFormat, "123.456E-0", resultPositive, SHOULD_PASS);
		test_parse_number(dotFormat, "123.456e0", resultPositive, SHOULD_PASS);
		test_parse_number(dotFormat, "123.456e+0", resultPositive, SHOULD_PASS);
		test_parse_number(dotFormat, "123.456e-0", resultPositive, SHOULD_PASS);
		
		// Negative numbers
		test_parse_number(dotFormat, "-123.456", resultNegative, SHOULD_PASS);
		test_parse_number(dotFormat, "-1.23456E2", resultNegative, SHOULD_PASS);
		test_parse_number(dotFormat, "-1.23456E+2", resultNegative, SHOULD_PASS);
		test_parse_number(dotFormat, "-1234.56E-1", resultNegative, SHOULD_PASS);
		test_parse_number(dotFormat, "-1.23456e2", resultNegative, SHOULD_PASS);
		test_parse_number(dotFormat, "-1.23456e+2", resultNegative, SHOULD_PASS);
		test_parse_number(dotFormat, "-1234.56e-1", resultNegative, SHOULD_PASS);
		test_parse_number(dotFormat, "-123.456E0", resultNegative, SHOULD_PASS);
		test_parse_number(dotFormat, "-123.456E+0", resultNegative, SHOULD_PASS);
		test_parse_number(dotFormat, "-123.456E-0", resultNegative, SHOULD_PASS);
		test_parse_number(dotFormat, "-123.456e0", resultNegative, SHOULD_PASS);
		test_parse_number(dotFormat, "-123.456e+0", resultNegative, SHOULD_PASS);
		test_parse_number(dotFormat, "-123.456e-0", resultNegative, SHOULD_PASS);
		
		// Invalid decimal separator
		test_parse_number(dotFormat, "123,456", Float.NaN, SHOULD_FAIL);
		
		java.text.NumberFormat decFormat = NumberFormatUtil.getNumberFormat(',', ';');
		test_parse_number(decFormat, "123,456", resultPositive, SHOULD_PASS);
		test_parse_number(decFormat, "1,23456E2", resultPositive, SHOULD_PASS);
		test_parse_number(decFormat, "1234,56e-1", resultPositive, SHOULD_PASS);
		test_parse_number(decFormat, "123.456", Float.NaN, SHOULD_FAIL);

		write("++Testing Number parser "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}

	static void write(String message)
	{
		System.out.println(message);
	}
	
	static void test_parse_number(java.text.NumberFormat format, String value, float expectedResult, boolean shouldFail)
	{
		try
		{
			Float fValue = (Float)Type.FLOAT.parseString(value, format, false);
			if (shouldFail)
			{
				throw new Exception("Parsing '" + value + "' should fail; got: " + fValue + "f");
			}
			if (fValue != expectedResult)
			{
				throw new Exception("Parsing '" + value + "' --> " + fValue + "f <> " + expectedResult + " (expected)");
			}
			write("--Parse string '" + value + "' --> " + fValue + "f OK");
		}
		catch (NumberFormatException ex)
		{
			if (!shouldFail)
			{
				write("--Parse string '" + value + "' --> " + expectedResult + "f FAILED");
				ex.printStackTrace();
				ok = false;
			}
			else
			{
				write("--Parse string '" + value + "' failed conversion as expected: " + ex.getMessage());				
			}
		}
		catch (Throwable t)
		{
			write("--Parse string '" + value + "' --> " + expectedResult + "f FAILED");
			t.printStackTrace();
			ok = false;
		}
	}

}

