/*
	$Id: TestPlateType.java 5340 2010-05-10 06:15:00Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
import net.sf.basedb.core.*;

import java.util.Date;
import java.util.Set;

public class TestPlateType
{

	static boolean ok = true;
	public static void main(String[] args)
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		ok = test_all();
		TestUtil.stop();
	}

	static boolean test_all()
	{
		write("++Testing plate types");
		write_header();
		// Standard tests: create, load, list
		int plateGeometryId = TestPlateGeometry.test_create(8, 12, false);
		int id = test_create(plateGeometryId, true);
		int id2 = test_create(plateGeometryId, false);
		test_load(id);
		test_list(-1);

		// Test events
		int protocolTypeId = TestProtocolType.test_create(false);
		int eventTypeId = test_create_event_type(id, protocolTypeId);
		test_list_event_types(id, 1);
		
		if (TestUtil.waitBeforeDelete()) TestUtil.waitForEnter();
		test_delete_event_type(eventTypeId);
		TestProtocolType.test_delete(protocolTypeId);
		
		// Standard test: Delete
		test_delete(id);
		test_delete(id2);
		TestPlateGeometry.test_delete(plateGeometryId);
		write("++Testing plate types "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}

	static int test_create(int plateGeometryId, boolean setAll)
	{
		if (plateGeometryId == 0 || !TestUtil.hasPermission(Permission.CREATE, Item.PLATETYPE)) return 0;
		int id = 0;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			PlateGeometry pg = PlateGeometry.getById(dc, plateGeometryId);
			PlateType pt = PlateType.getNew(dc, pg);
			if (setAll)
			{
				pt.setName("Test plate type");
				pt.setDescription("Added at "+new Date());
			}
			dc.saveItem(pt);
			dc.commit();
			id = pt.getId();
			dc = TestUtil.getDbControl();
			dc.reattachItem(pt, false);
			write_item(0, pt);
			write("--Create plate type OK");
		}
		catch (Throwable ex)
		{
			write("--Create plate type FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
		return id;
	}

	static void test_load(int id)
	{
		if (id == 0) return;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			PlateType pg = PlateType.getById(dc, id);
			write_item(0, pg);
			write("--Load plate type OK");
		}
		catch (Throwable ex)
		{
			write("--Load plate type FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}


	static void test_list(int expectedResults)
	{
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			ItemResultList<PlateType> l = PlateType.getQuery().list(dc);
			for (int i = 0; i<l.size(); i++)
			{
				write_item(i, l.get(i));
			}
			if (expectedResults >= 0 && expectedResults != l.size())
			{
				throw new BaseException("Expected "+expectedResults+" results, not "+l.size());
			}
			write("--List plate types OK ("+l.size()+")");
		}
		catch (Throwable ex)
		{
			write("--List plate types FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}


	static void test_delete(int id)
	{
		if (id == 0) return;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			PlateType pt = PlateType.getById(dc, id);
			dc.deleteItem(pt);
			Set<ItemProxy> using = pt.getUsingItems();
			if (using.size() > 0) 
			{
			   throw new BaseException(pt + " is used by " + using);
			}
			dc.commit();
			write("--Delete plate type OK");
		}
		catch (Throwable ex)
		{
			write("--Delete plate type FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}

	static void write_header()
	{
		if (!TestUtil.getSilent())
		{
			System.out.println("   \tID \tName      \tDescription\tPlate geometry");
			System.out.println("-- \t-- \t--------- \t-----------\t--------------");
		}
	}
	static void write_item(int i, PlateType pt)
		throws BaseException
	{
		if (!TestUtil.getSilent()) System.out.println(i+":\t"+pt.getId()+"\t"+pt.getName()+"\t"+pt.getDescription()+
			"\t"+pt.getPlateGeometry());
	}
	static void write_item(int i, PlateEventType pet)
		throws BaseException
	{
		if (!TestUtil.getSilent()) System.out.println(i+":\t"+pet.getId()+"\t"+pet.getName()+"\t"+pet.getDescription()+
			"\t"+pet.getPlateType()+"\t"+pet.getOrdinal()+"\t"+pet.getProtocolType());
	}
	static void write(String message)
	{
		System.out.println(message);
	}

	static int test_create_event_type(int plateTypeId, int protocolTypeId)
	{
		if (plateTypeId == 0) return 0;
		int id = 0;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			PlateType pt = PlateType.getById(dc, plateTypeId);
			PlateEventType pet = pt.newEventType();
			pet.setName("Test plate event type");
			pet.setDescription("Added at "+new Date());
			pet.setOrdinal(1);
			if (protocolTypeId != 0) pet.setProtocolType(ProtocolType.getById(dc, protocolTypeId));
			dc.saveItem(pet);
			dc.commit();
			id = pet.getId();
			dc = TestUtil.getDbControl();
			dc.reattachItem(pet, false);
			write_item(0, pet);
			write("--Create event type OK");
		}
		catch (Exception ex)
		{
			write("--Create event type FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
		return id;
	}
	
	static void test_list_event_types(int plateTypeId, int expectedResults)
	{
		if (plateTypeId == 0) return;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			PlateType pt = PlateType.getById(dc, plateTypeId);
			
			ItemResultList<PlateEventType> l = pt.getEventTypes().list(dc);
			for (int i = 0; i<l.size(); i++)
			{
				write_item(i, l.get(i));
			}
			if (expectedResults >= 0 && expectedResults != l.size())
			{
				throw new BaseException("Expected "+expectedResults+" results, not "+l.size());
			}
			write("--List event types OK ("+l.size()+")");
		}
		catch (Exception ex)
		{
			write("--List event types FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}

	static void test_delete_event_type(int eventTypeId)
	{
		if (eventTypeId == 0) return;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			PlateEventType pet = PlateEventType.getById(dc, eventTypeId);
			dc.deleteItem(pet);
			dc.commit();
			write("--Delete event type OK");
		}
		catch (Exception ex)
		{
			write("--Delete event type FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}

}
