import java.util.Date;
import java.util.Set;

import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemProxy;
import net.sf.basedb.core.Permission;
import net.sf.basedb.core.ItemResultList;
import net.sf.basedb.core.Software;
import net.sf.basedb.core.SoftwareType;
import net.sf.basedb.core.SystemItems;

/*
 $Id$

	Copyright (C) 2005 Johan Enell, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

 BASE is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 3
 of the License, or (at your option) any later version.

 BASE is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with BASE. If not, see <http://www.gnu.org/licenses/>.
 */

public class TestSoftware
{
	static boolean ok = true;
	public static void main(String[] args)
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		ok = test_all();
		TestUtil.stop();
	}

	static boolean test_all()
	{
		write("++Testing software");
		write_header();
		// Standard tests: create, load, list
		int id1 = test_create(SystemItems.getId(SoftwareType.FEATURE_EXTRACTION),null, true);
		int id2 = test_create(SystemItems.getId(SoftwareType.FEATURE_EXTRACTION), null, false);
		test_load(id1);
		test_list();

		// Extra tests:

		// Standard test: Delete
		if (TestUtil.waitBeforeDelete()) TestUtil.waitForEnter();
		test_delete(id1);
		test_delete(id2);
		write("++Testing software "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}

	static int test_create(int softwareTypeId, String name, boolean setAll)
	{
		if (!TestUtil.hasPermission(Permission.CREATE, Item.SOFTWARE)) return 0;
		int id = 0;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			SoftwareType st = SoftwareType.getById(dc, softwareTypeId);
			Software sw = Software.getNew(dc, st);
			if (setAll)
			{
				sw.setName("Test software");
				sw.setDescription("Added at "+new Date());
				sw.setVersionString("0.9 beta");
			}
			if (name != null) sw.setName(name);
			dc.saveItem(sw);
			dc.commit();
			id = sw.getId();
			dc = TestUtil.getDbControl();
			dc.reattachItem(sw, false);
			write_item(0, sw);
			write("--Create software OK");
		}
		catch (Throwable ex)
		{
			write("--Create software FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
		return id;
	}

	static void test_load(int id)
	{
		if (id == 0) return;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			Software sw = Software.getById(dc, id);
			write_item(0, sw);
			write("--Load software OK");
		}
		catch (Throwable ex)
		{
			write("--Load software FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}

	static void test_list()
	{
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			ItemResultList<Software> l = Software.getQuery().list(dc);
			for (int i = 0; i<l.size(); i++)
			{
				write_item(i, (Software)l.get(i));
			}
			write("--List software OK ("+l.size()+")");
		}
		catch (Throwable ex)
		{
			write("--List software FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}

	static void test_delete(int id)
	{
		if (id == 0) return;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			Software sw = Software.getById(dc, id);
			dc.deleteItem(sw);
			Set<ItemProxy> using = sw.getUsingItems();
			if (using.size() > 0) 
			{
			   throw new BaseException(sw + " is used by " + using);
			}
			dc.commit();
			write("--Delete software OK");
		}
		catch (Throwable ex)
		{
			write("--Delete software FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}

	static void write_header()
	{
		if (!TestUtil.getSilent())
		{
			write("   \tID \tName      \tDescription\tVersion\tType");
			write("-- \t-- \t--------- \t-----------\t-------\t----");
		}
	}
	static void write_item(int i, Software sw)
		throws BaseException
	{
		if (!TestUtil.getSilent()) System.out.println(i+":\t"+sw.getId()+"\t"+sw.getName()+"\t"+sw.getDescription()+"\t"+sw.getVersionString()+"\t"+sw.getSoftwareType().getName());
	}
	static void write(String message)
	{
		System.out.println(message);
	}
}
