/**
	$Id: MouseData.java 4514 2008-09-11 20:07:12Z jari $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.test;

import java.util.HashMap;
import java.util.Map;

/**
	Helper class for getting parameters to import plugins for the mouse data
	set in /testdata/mouse.

	@author nicklas
	@version 2.2
	@base.modified $Date: 2008-09-11 22:07:12 +0200 (Thu, 11 Sep 2008) $
*/
public class MouseData
{

	/**
		Get configuration parameters required for the reporter importer.
	*/
	public static Map<String, Object> getReporterParameters()
	{
		Map<String, Object> parameters = new HashMap<String, Object>();
		parameters.put("dataSplitterRegexp", "\\t");
		parameters.put("dataHeaderRegexp", "384_number\\t384_column\\t384_row\\t384_position\\toligo_id.*");
		parameters.put("minDataColumns", 5);
	
		parameters.put("reporterIdColumnMapping", "\\oligo_id\\");
		parameters.put("nameColumnMapping", "\\oligo_id\\");
		parameters.put("symbolColumnMapping", "\\gene_symbol_Ensembl*\\");
		parameters.put("descriptionColumnMapping", "\\description_Ensembl*\\");
	
		parameters.put("extendedColumnMapping.sequence", "\\oligo_sequence\\");
		return parameters;
	}

	/**
		Get configuration parameters required for importing reporters from a GenePix raw data file.
	*/
	public static Map<String, Object> getGenePixReporterParameters()
	{
		Map<String, Object> parameters = new HashMap<String, Object>();
		parameters.put("dataSplitterRegexp", "\\t");
		parameters.put("dataHeaderRegexp", "\"Block\"\\t\"Column\"\\t\"Row\"\\t\"Name\"\\t\"ID\".*");
		parameters.put("minDataColumns", 48);
		parameters.put("maxDataColumns", 48);			
	
		parameters.put("reporterIdColumnMapping", "\\ID\\");
		parameters.put("nameColumnMapping", "\\Name\\");
		
		// No extended properties are available in the file
		return parameters;
	}

	/**
		Get configuration parameters required for importing features from a GenePix raw data file.
	*/
	public static Map<String, Object> getGenePixReporterMapParameters()
	{
		Map<String, Object> parameters = new HashMap<String, Object>();
		parameters.put("dataSplitterRegexp", "\\t");
		parameters.put("dataHeaderRegexp", "\"Block\"\\t\"Column\"\\t\"Row\"\\t\"Name\"\\t\"ID\".*");
		parameters.put("minDataColumns", 48);
		parameters.put("maxDataColumns", 48);			
	
		parameters.put("reporterIdColumnMapping", "\\ID\\");
		parameters.put("blockColumnMapping", "\\Block\\");
		parameters.put("columnColumnMapping", "\\Column\\");
		parameters.put("rowColumnMapping", "\\Row\\");
		
		return parameters;
	}

	/**
		Get configuration parameters required for the raw data importer.
	*/
	public static Map<String, Object> getGenePixRawDataParameters(boolean dyeSwap)
	{
		Map<String, Object> parameters = new HashMap<String, Object>();
		parameters.put("rawDataType", "genepix");
		parameters.put("headerRegexp", "\"(.+)=(.*)\"");
		parameters.put("dataSplitterRegexp", "\\t");
		//parameters.put("ignoreRegexp", ".*(NoOligoInfo|no clone).*");
		if (dyeSwap)
		{
			parameters.put("dataHeaderRegexp", "\"Block\"\\t\"Column\"\\t\"Row\"\\t\"Name\"\\t\"ID\".*\"Ratio of Medians \\(635\\/532\\)\".*");		
		}
		else
		{
			parameters.put("dataHeaderRegexp", "\"Block\"\\t\"Column\"\\t\"Row\"\\t\"Name\"\\t\"ID\".*\"Ratio of Medians \\(532\\/635\\)\".*");
		}
		parameters.put("minDataColumns", 48);
		parameters.put("maxDataColumns", 48);			
	
		parameters.put("blockColumnMapping", "\\Block\\");
		parameters.put("columnColumnMapping", "\\Column\\");
		parameters.put("rowColumnMapping", "\\Row\\");
		parameters.put("reporterIdColumnMapping", "\\ID\\");
		parameters.put("xColumnMapping", "\\X\\");
		parameters.put("yColumnMapping", "\\Y\\");
		parameters.put("propertyMapping.diameter", "\\Dia.\\");
		int chF635 = dyeSwap ? 2 : 1;
		int chF532 = dyeSwap ? 1 : 2;
		parameters.put("propertyMapping.ch"+chF635+"FgMedian", "\\F635 Median\\");
		parameters.put("propertyMapping.ch"+chF635+"FgMean", "\\F635 Mean\\");
		parameters.put("propertyMapping.ch"+chF635+"FgSd", "\\F635 SD\\");
		parameters.put("propertyMapping.ch"+chF635+"BgMedian", "\\B635 Median\\");
		parameters.put("propertyMapping.ch"+chF635+"BgMean", "\\B635 Mean\\");
		parameters.put("propertyMapping.ch"+chF635+"BgSd", "\\B635 SD\\");
		parameters.put("propertyMapping.ch"+chF635+"PercSd1", "\\% > B635+1SD\\");
		parameters.put("propertyMapping.ch"+chF635+"PercSd2", "\\% > B635+2SD\\");
		parameters.put("propertyMapping.ch"+chF635+"PercSat", "\\F635 % Sat.\\");
		
		parameters.put("propertyMapping.ch"+chF532+"FgMedian", "\\F532 Median\\");
		parameters.put("propertyMapping.ch"+chF532+"FgMean", "\\F532 Mean\\");
		parameters.put("propertyMapping.ch"+chF532+"FgSd", "\\F532 SD\\");
		parameters.put("propertyMapping.ch"+chF532+"BgMedian", "\\B532 Median\\");
		parameters.put("propertyMapping.ch"+chF532+"BgMean", "\\B532 Mean\\");
		parameters.put("propertyMapping.ch"+chF532+"BgSd", "\\B532 SD\\");
		parameters.put("propertyMapping.ch"+chF532+"PercSd1", "\\% > B532+1SD\\");
		parameters.put("propertyMapping.ch"+chF532+"PercSd2", "\\% > B532+2SD\\");
		parameters.put("propertyMapping.ch"+chF532+"PercSat", "\\F532 % Sat.\\");
		
		parameters.put("propertyMapping.fgPixels", "\\F Pixels\\");
		parameters.put("propertyMapping.bgPixels", "\\B Pixels\\");
		parameters.put("propertyMapping.flags", "\\Flags\\");
	
		return parameters;
	}

	/**
		Get configuration parameters required for the plate importer.
	*/
	public static Map<String, Object> getPlateParameters()
	{
		Map<String, Object> parameters = new HashMap<String, Object>();
		parameters.put("dataSplitterRegexp", "\\t");
		parameters.put("dataHeaderRegexp", "384_number\\t384_column\\t384_row\\t384_position\\toligo_id.*");
		parameters.put("minDataColumns", 5);		
	
		parameters.put("reporterColumnMapping", "\\oligo_id\\");
		parameters.put("nameColumnMapping", "\\384_number\\");
		parameters.put("rowColumnMapping", "\\384_row\\");
		parameters.put("columnColumnMapping", "\\384_column\\");
	
		return parameters;
	}

}
