<%-- $Id: list_formulas.jsp 5426 2010-09-24 09:18:50Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson
	Copyright (C) 2007 Johan Enell, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.Formula"
	import="net.sf.basedb.core.Type"
	import="net.sf.basedb.core.IntensityTransform"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.ItemResultIterator"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Nameable"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.RawDataTypes"
	import="net.sf.basedb.core.RawDataType"
	import="net.sf.basedb.core.PluginDefinition"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.core.plugin.Plugin"
	import="net.sf.basedb.util.Enumeration"
	import="net.sf.basedb.util.ShareableUtil"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.ModeInfo"
	import="net.sf.basedb.clients.web.PermissionUtil"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.renderer.PrefixSuffixRenderer"
	import="net.sf.basedb.clients.web.extensions.toolbar.ToolbarUtil"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.Date"
	import="java.util.Iterator"
	import="java.util.List"
	import="java.util.Map"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%!
	private static final Item itemType = Item.FORMULA;
	private static final GuiContext guiContext = new GuiContext(itemType, GuiContext.Type.LIST);
	
	private static final Enumeration<String, String> types = new Enumeration<String, String>();
	private static final Enumeration<String, String> parsers = new Enumeration<String, String>();
	private static final Enumeration<String, String> avgMethods = new Enumeration<String, String>();
	private static final Enumeration<String, String> transforms = new Enumeration<String, String>();
	private static final Enumeration<String, String> rawEnumeration = new Enumeration<String, String>();
	private static final Enumeration<String, String> valueTypes = new Enumeration<String, String>();
	static
	{
		for (Formula.Type t : Formula.Type.values())
		{
			types.add(Integer.toString(t.getValue()), HTML.encodeTags(t.toString()));
		}
		valueTypes.add("", "- unknown -");
		for (Type v : Type.values())
		{
			valueTypes.add(Integer.toString(v.getValue()), v.toString());
		}
		for (Formula.Parser p : Formula.Parser.values())
		{
			parsers.add(Integer.toString(p.getValue()), HTML.encodeTags(p.toString()));
		}
		for (Formula.AverageMethod m : Formula.AverageMethod.values())
		{
			avgMethods.add(Integer.toString(m.getValue()), HTML.encodeTags(m.toString()));
		}
		transforms.add("", "- any -");
		for (IntensityTransform t : IntensityTransform.values())
		{
			transforms.add(Integer.toString(t.getValue()), HTML.encodeTags(t.toString()));
		}
		rawEnumeration.add("", "- none -");
		for (RawDataType rdt : RawDataTypes.getRawDataTypes())
		{
			rawEnumeration.add(rdt.getId(), HTML.encodeTags(rdt.getName()));
		}
	}
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, Permission.DENIED, itemType);
final String ID = sc.getId();
final boolean createPermission = sc.hasPermission(Permission.CREATE, itemType);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);

final ModeInfo mode = ModeInfo.get(request.getParameter("mode"));
final String callback = request.getParameter("callback");
final String title = mode.generateTitle("formula", "formulas");
final DbControl dc = sc.newDbControl();
ItemResultIterator<Formula> formulas = null;
try
{
	Formatter<Date> dateFormatter = FormatterFactory.getDateFormatter(sc);
	Map<Plugin.MainType, Integer> pluginCount = PluginDefinition.countPlugins(dc, guiContext);
	try
	{
		final ItemQuery<Formula> query = Base.getConfiguredQuery(dc, cc, true, Formula.getQuery(), mode);
		formulas = query.iterate(dc);
	}
	catch (Throwable t)
	{
		t.printStackTrace();
		cc.setMessage(t.getMessage());
	}
	int numListed = 0;
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, guiContext, null);
	ExtensionsInvoker invoker = ToolbarUtil.useExtensions(jspContext);
	%>
	<base:page title="<%=title==null ? "Formulas" : title%>" type="<%=mode.getPageType()%>">
	<base:head scripts="menu.js,table.js" styles="menu.css,table.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
		<script language="JavaScript">
		var submitPage = 'index.jsp';
		var formId = 'formulas';
		function newItem()
		{
			Main.viewOrEditItem('<%=ID%>', '<%=itemType.name()%>', 0, true);
		}
		function editItem(itemId)
		{
			Main.viewOrEditItem('<%=ID%>', '<%=itemType.name()%>', itemId, true);
		}
		function viewItem(itemId)
		{
			Main.viewOrEditItem('<%=ID%>', '<%=itemType.name()%>', itemId, false);
		}
		function itemOnClick(evt, itemId)
		{
			Table.itemOnClick(formId, evt, itemId, '<%=mode.getName()%>', viewItem, editItem, returnSelected);
		}
		function deleteItems()
		{
			var frm = document.forms[formId];
			if (Forms.numChecked(frm) == 0)
			{
				alert('Please select at least one item in the list');
				return; 
			}
			frm.action = submitPage;
			frm.cmd.value = 'DeleteItems';
			frm.submit();
		}
		function restoreItems()
		{
			var frm = document.forms[formId];
			if (Forms.numChecked(frm) == 0)
			{
				alert('Please select at least one item in the list');
				return; 
			}
			frm.action = submitPage;
			frm.cmd.value = 'RestoreItems';
			frm.submit();
		}
		function deleteItemPermanently(itemId)
		{
			Main.deleteItemPermanently('<%=ID%>', true, '<%=itemType.name()%>', itemId);
		}
		function setOwner()
		{
			Table.setOwnerOfItems(submitPage, '<%=ID%>', formId, '<%=itemType.name()%>', 'SetOwnerOfItems');
		}
		function shareItem(itemId)
		{
			Main.openPopup('index.jsp?ID=<%=ID%>&cmd=ShareItem&item_id='+itemId, 'ShareItem', 600, 400);
		}
		function shareItems()
		{
			Table.shareItems(submitPage, '<%=ID%>', formId, '<%=itemType.name()%>', 'ShareItems');
		}
		function configureColumns()
		{
			Table.configureColumns('<%=ID%>', formId, '<%=itemType.name()%>', '<%=(String)cc.getObject("defaultColumns")%>');
		}
		function runPlugin(cmd)
		{
			Table.submitToPopup(formId, cmd, 740, 540);
		}
		function returnSelected()
		{
			Table.returnSelected(formId, <%=callback != null ? "window.opener."+callback : "null" %>);
			window.close();
		}
		function presetOnChange()
		{
			Table.presetOnChange('<%=ID%>', formId, '<%=itemType.name()%>', '<%=(String)cc.getObject("defaultColumns")%>');
		}
		</script>
	</base:head>
	
	<base:body>
		<%
		if (cc.getMessage() != null)
		{
			%>
			<div class="error"><%=cc.getMessage()%></div>
			<%
			cc.setMessage(null);
		}
		%>
		<tbl:table 
			id="formulas" 
			clazz="itemlist" 
			columns="<%=cc.getSetting("columns")%>"
			sortby="<%=cc.getSortProperty()%>" 
			direction="<%=cc.getSortDirection()%>"
			title="<%=title%>"
			action="index.jsp"
			sc="<%=sc%>"
			item="<%=itemType%>"
			>
			<tbl:hidden 
				name="mode" 
				value="<%=mode.getName()%>" 
			/>
			<tbl:hidden 
				name="callback" 
				value="<%=callback%>" 
				skip="<%=callback == null%>" 
			/>
			<tbl:columndef 
				id="name"
				property="name"
				datatype="string"
				title="Name"
				sortable="true" 
				filterable="true"
				exportable="true"
				show="always" 
			/>
			<tbl:columndef 
				id="id"
				clazz="uniquecol"
				property="id"
				datatype="int"
				title="ID"
				sortable="true"
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="entryDate"
				property="entryDate"
				datatype="date"
				title="Registered"
				sortable="true" 
				filterable="true"
				exportable="true"
				formatter="<%=dateFormatter%>"
			/>
			<tbl:columndef 
				id="type"
				property="type"
				datatype="int"
				enumeration="<%=types%>"
				title="Type"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="parser"
				property="parser"
				datatype="int"
				enumeration="<%=parsers%>"
				title="Parser"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="valueType"
				property="valueType"
				datatype="int"
				enumeration="<%=valueTypes%>"
				title="Value type"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="averageMethod"
				property="averageMethod"
				datatype="int"
				enumeration="<%=avgMethods%>"
				title="Avg. method"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="sourceIntensityTransform"
				property="sourceIntensityTransform"
				datatype="int"
				enumeration="<%=transforms%>"
				title="Source intensity transform"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="resultIntensityTransform"
				property="resultIntensityTransform"
				datatype="int"
				enumeration="<%=transforms%>"
				title="Result intensity transform"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="rawDataType"
				property="rawDataType"
				datatype="string"
				enumeration="<%=rawEnumeration%>"
				title="Raw data type"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="channels"
				property="channels"
				datatype="int"
				title="Channels"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="formulas"
				property="formulas"
				datatype="string"
				title="Formulas"
				sortable="false" 
				filterable="false"
				exportable="true"
			/>
			<tbl:columndef 
				id="useColors"
				property="coloring#usingColors"
				datatype="boolean"
				title="Use colors"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="logarithmic"
				property="coloring#logarithmic"
				datatype="boolean"
				title="Logarithmic"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="minValue"
				property="coloring#minValue"
				datatype="float"
				title="Min value"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="midValue"
				property="coloring#midValue"
				datatype="float"
				title="Mid value"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="maxValue"
				property="coloring#maxValue"
				datatype="float"
				title="Max value"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="owner"
				property="owner.name"
				datatype="string"
				title="Owner"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="description"
				property="description"
				datatype="string"
				title="Description" 
				sortable="true" 
				filterable="true" 
				exportable="true"
			/>
			<tbl:columndef
				id="permission"
				title="Permission"
			/>
			<tbl:columndef
				id="sharedTo"
				title="Shared to"
				filterable="true"
				filterproperty="!sharedTo.name"
				datatype="string"
			/>
			<tbl:toolbar
				visible="<%=mode.hasToolbar()%>"
				>
				<tbl:button 
					disabled="<%=createPermission ? false : true%>" 
					image="<%=createPermission ? "new.gif" : "new_disabled.gif"%>" 
					onclick="newItem()" 
					title="New&hellip;" 
					tooltip="<%=createPermission ? "Create new formula" : "You do not have permission to create formulas"%>" 
				/>
				<tbl:button 
					image="delete.gif"
					onclick="deleteItems()" 
					title="Delete" 
					tooltip="Delete the selected items" 
				/>
				<tbl:button 
					image="restore.gif"
					onclick="restoreItems()" 
					title="Restore" 
					tooltip="Restore the selected (deleted) items"
				/>
				<tbl:button 
					image="share.gif"
					onclick="shareItems()" 
					title="Share&hellip;" 
					tooltip="Share the selected items"
				/>
				<tbl:button 
					image="take_ownership.png"
					onclick="setOwner()" 
					title="Set owner&hellip;"
					tooltip="Change owner of the selected items"
				/>
				<tbl:button 
					image="columns.gif" 
					onclick="configureColumns()" 
					title="Columns&hellip;" 
					tooltip="Show, hide and re-order columns" 
				/>
				<tbl:button 
					image="import.gif" 
					onclick="runPlugin('ImportItems')" 
					title="Import&hellip;" 
					tooltip="Import data" 
					visible="<%=pluginCount.containsKey(Plugin.MainType.IMPORT)%>"
				/>
				<tbl:button 
					image="export.gif" 
					onclick="runPlugin('ExportItems')" 
					title="Export&hellip;" 
					tooltip="Export data" 
					visible="<%=pluginCount.containsKey(Plugin.MainType.EXPORT)%>"
				/>
				<tbl:button 
					image="runplugin.gif" 
					onclick="runPlugin('RunListPlugin')" 
					title="Run plugin&hellip;" 
					tooltip="Run a plugin" 
					visible="<%=pluginCount.containsKey(Plugin.MainType.OTHER)%>"
				/>
				<ext:render extensions="<%=invoker%>" context="<%=jspContext%>" 
					wrapper="<%=new PrefixSuffixRenderer(jspContext, "<td>", "</td>") %>"/>
			</tbl:toolbar>
			<tbl:navigator
				page="<%=cc.getPage()%>" 
				rowsperpage="<%=cc.getRowsPerPage()%>" 
				totalrows="<%=formulas == null ? 0 : formulas.getTotalCount()%>" 
				visible="<%=mode.hasNavigator()%>"
			/>
			<tbl:data>
				<tbl:columns>
				<tbl:presetselector 
					clazz="columnheader"
					colspan="3"
					onchange="presetOnChange()"
				/>
				</tbl:columns>

				<tr>
					<tbl:header 
						clazz="index"
						>&nbsp;</tbl:header>
					<tbl:header 
						clazz="check" 
						visible="<%=mode.hasCheck()%>"
						><base:icon 
							image="check_uncheck.gif" 
							tooltip="Check/uncheck all" 
							onclick="Forms.checkUncheck(document.forms[formId])" style="align: left;"
						/></tbl:header>
					<tbl:header 
						clazz="check" 
						visible="<%=mode.hasRadio()%>"
						>&nbsp;</tbl:header>
					<tbl:header 
						clazz="icons" 
						visible="<%=mode.hasIcons()%>"
						>&nbsp;</tbl:header>
					<tbl:propertyfilter />
				</tr>
					
					<tbl:rows>
					<%
					int index = cc.getPage()*cc.getRowsPerPage();
					int selectedItemId = cc.getId();
					if (formulas != null)
					{
						while (formulas.hasNext())
						{
							Formula item = formulas.next();
							RawDataType rawDataType = item.getRawDataType();
							List<String> expressions = item.getFormulas();
							int itemId = item.getId();
							String openSharePopup = "shareItem("+itemId+")";
							String deletePermanently = "deleteItemPermanently("+itemId+")";
							boolean deletePermission = item.hasPermission(Permission.DELETE);
							boolean sharePermission = item.hasPermission(Permission.SET_PERMISSION);
							boolean writePermission = item.hasPermission(Permission.WRITE);
							String tooltip = mode.isSelectionMode() ?
									"Select this item" : "View this item" + (writePermission ? " (use CTRL, ALT or SHIFT to edit)" : "");
							String name = HTML.encodeTags(item.getName());
							index++;
							numListed++;
							%>
							<tbl:row>
								<tbl:header 
									clazz="index"
									><%=index%></tbl:header>
								<tbl:header 
									clazz="check" 
									visible="<%=mode.hasCheck()%>"
									><input 
										type="checkbox" 
										name="<%=itemId%>" 
										value="<%=itemId%>" 
										title="<%=name%>" 
										<%=cc.getSelected().contains(itemId) ? "checked" : ""%> 
									></tbl:header>
								<tbl:header 
									clazz="check" 
									visible="<%=mode.hasRadio()%>"
									><input 
										type="radio" 
										name="item_id" 
										value="<%=itemId%>" 
										title="<%=name%>" 
										<%=selectedItemId == itemId ? "checked" : ""%>
									></tbl:header>
								<tbl:header 
									clazz="icons" 
									visible="<%=mode.hasIcons()%>"
									><base:icon 
										image="<%=deletePermission ? "deleted.gif" : "deleted_disabled.gif"%>"
										onclick="<%=deletePermission ? deletePermanently : null%>"
										tooltip="This item has been scheduled for deletion" 
										visible="<%=item.isRemoved()%>"
									/><base:icon 
										image="<%=sharePermission ? "shared.gif" : "shared_disabled.gif"%>" 
										onclick="<%=sharePermission ? openSharePopup : null%>"
										tooltip="This item is shared to other users, groups and/or projects" 
										visible="<%=item.isShared()%>"
									/>&nbsp;</tbl:header>
								<tbl:cell column="name"><div class="link" 
									onclick="itemOnClick(<%=writePermission ? "event" : null%>, <%=itemId%>)" 
									title="<%=tooltip%>"><%=name%></div></tbl:cell>
								<tbl:cell column="id"><%=item.getId()%></tbl:cell>
								<tbl:cell column="entryDate" value="<%=item.getEntryDate()%>" />
								<tbl:cell column="type"><%=item.getFormulaType().toString()%></tbl:cell>
								<tbl:cell column="parser"><%=item.getParser().toString()%></tbl:cell>
								<tbl:cell column="valueType"><%=item.getValueType() == null ? "<i>- unknown -</i>" : item.getValueType()%></tbl:cell>
								<tbl:cell column="averageMethod"><%=item.getAverageMethod().toString()%></tbl:cell>
								<tbl:cell column="sourceIntensityTransform"><%=item.getSourceIntensityTransform() == null ? "<i>- any -</i>" : item.getSourceIntensityTransform().toString()%></tbl:cell>
								<tbl:cell column="resultIntensityTransform"><%=item.getResultIntensityTransform() == null ? "<i>- any -</i>" : item.getResultIntensityTransform().toString()%></tbl:cell>
								<tbl:cell column="rawDataType"><%=rawDataType == null ? "<i>- none -</i>" : HTML.encodeTags(rawDataType.getName())%></tbl:cell>
								<tbl:cell column="channels"><%=item.getChannels()%></tbl:cell>
								<tbl:cell column="formulas">
								<%
								for (int i = 0; i < expressions.size(); ++i)
								{
									%>
									<%=(i+1) + ": " + HTML.encodeTags(expressions.get(i))%><br>
									<%
								}
								%>
								</tbl:cell>
								<tbl:cell column="owner"
									><base:propertyvalue 
										item="<%=item%>" 
										property="owner"
										enableEditLink="<%=mode.hasEditLink()%>" 
										enablePropertyLink="<%=mode.hasPropertyLink()%>"
									/></tbl:cell>
								<tbl:cell column="useColors"><%=item.getColoring().isUsingColors() ? "yes" : "no"%></tbl:cell>
								<tbl:cell column="logarithmic"><%=item.getColoring().isLogarithmic() ? "yes" : "no"%></tbl:cell>
								<tbl:cell column="minValue"><%=Values.formatNumber(item.getColoring().getMinValue(), 2)%></tbl:cell>
								<tbl:cell column="midValue"><%=Values.formatNumber(item.getColoring().getMidValue(), 2)%></tbl:cell>
								<tbl:cell column="maxValue"><%=Values.formatNumber(item.getColoring().getMaxValue(), 2)%></tbl:cell>
								<tbl:cell column="description"><%=HTML.encodeTags(item.getDescription())%></tbl:cell>
								<tbl:cell column="permission"><%=PermissionUtil.getShortPermissions(item)%></tbl:cell>
								<tbl:cell column="sharedTo">
									<%
									Iterator<Nameable> sharees = ShareableUtil.getSharedTo(dc, item).iterator();
									while(sharees.hasNext())
									{
										Nameable n = sharees.next();
										if (mode.hasPropertyLink())
										{
											out.write(Base.getLinkedName(ID, n, false, mode.hasEditLink()));
										}
										else
										{
											out.write(HTML.encodeTags(n.getName()));
										}
										out.write(sharees.hasNext() ? ", " : "");
									}
									%>
								</tbl:cell>
							</tbl:row>
							<%
							}
						}
					%>
					</tbl:rows>
			</tbl:data>
			<%
			if (numListed == 0)
			{
				%>
				<tbl:panel><%=formulas == null || formulas.getTotalCount() == 0 ? "No formulas were found" : "No formulas on this page. Please select another page!" %></tbl:panel>
				<%
			}
			else
			{
				%>
				<tbl:navigator
					page="<%=cc.getPage()%>" 
					rowsperpage="<%=cc.getRowsPerPage()%>" 
					totalrows="<%=formulas == null ? 0 : formulas.getTotalCount()%>" 
					visible="<%=mode.hasNavigator()%>"
					locked="true"
				/>
				<%
			}
			%>
		</tbl:table>
		<base:buttongroup align="center" clazz="fixedatbottom">
			<base:button onclick="returnSelected();" title="Ok" visible="<%=mode.hasOkButton()%>" />
			<base:button onclick="window.close();" title="Cancel" visible="<%=mode.hasCancelButton()%>" />
			<base:button onclick="window.close();" title="Close" visible="<%=mode.hasCloseButton()%>" />
		</base:buttongroup>
		<br><br><br>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (formulas != null) formulas.close();
	if (dc != null) dc.close();
}
%>
