<%-- $Id: edit_reporter.jsp 5432 2010-09-29 09:21:45Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Johan Enell, Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.ExtendedProperties"
	import="net.sf.basedb.core.ExtendedProperty"
	import="net.sf.basedb.core.Type"
	import="net.sf.basedb.core.Reporter"
	import="net.sf.basedb.core.ReporterType"
	import="net.sf.basedb.core.data.ReporterData"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.ItemResultIterator"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="net.sf.basedb.clients.web.formatter.FormatterSettings"
	import="java.util.Date"
	import="java.util.List"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%
final Item itemType = Item.REPORTER;
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl();
ItemResultIterator<ReporterType> reporterTypes = null;
try
{
	List<ExtendedProperty> reporterProperties = ExtendedProperties.getProperties("ReporterData");
	
	String title = null;
	ReporterData reporter = null;
	boolean readCurrentReporterType = true;
	int currentReporterTypeId = 0;
	
	if (itemId == 0)
	{
		int recentType = Values.getInt(cc.getRecent(Item.REPORTERTYPE.name(), 0), 0);
		currentReporterTypeId = Values.getInt(cc.getPropertyValue("reporterType"), recentType);
		title = "Create reporter";
		cc.removeObject("item");
	}
	else
	{
		reporter = Reporter.getById(dc, itemId);
		title = "Edit reporter -- " + HTML.encodeTags(reporter.getName());
		try
		{
			ReporterType rt = Reporter.getReporterType(dc, reporter);
			if (rt != null) 
			{
				currentReporterTypeId = rt.getId();
			}
		}
		catch (PermissionDeniedException ex)
		{
			readCurrentReporterType = false;
		}
		cc.setObject("item", reporter);
	}
	if (!sc.hasPermission(Permission.WRITE, itemType))
	{
		throw new PermissionDeniedException(Permission.WRITE, itemType.toString());
	}
	
	final String clazz = "class=\"text\"";
	final String requiredClazz = "class=\"text required\"";


	// Query to retrieve reporter types
	final ItemQuery<ReporterType> reporterTypeQuery = ReporterType.getQuery();
	reporterTypeQuery.order(Orders.asc(Hql.property("name")));
	Formatter<Date> dateFormatter = FormatterFactory.getDateFormatter(sc);
	String dateFormat = FormatterSettings.getDateFormat(sc);
	String jsDateFormat = HTML.javaScriptEncode(dateFormat);
	String htmlDateFormat = HTML.encodeTags(dateFormat);
	Formatter<Date> dateTimeFormatter = FormatterFactory.getDateTimeFormatter(sc);
	String dateTimeFormat = FormatterSettings.getDateTimeFormat(sc);
	String jsDateTimeFormat = HTML.javaScriptEncode(dateTimeFormat);
	String htmlDateTimeFormat = HTML.encodeTags(dateTimeFormat);
	%>
	<base:page type="popup" title="<%=title%>">
	<base:head scripts="tabcontrol.js" styles="tabcontrol.css">
		<script language="JavaScript">
		// Validate the "Reporter" tab
		function validateReporter()
		{
			var frm = document.forms['reporter'];
			if (Main.trimString(frm.name.value) == '')
			{
				alert("You must enter a name for the reporter.");
				frm.name.focus();
				return false;
			}
			else if (Main.trimString(frm.externalId.value) == '')
			{
				alert("You must enter an external ID for the reporter.");
				frm.externalId.focus();
				return false;
			}
			return true;
		}
		// Validate the "Extended properties" tab
		function validateExtendedProperties()
		{
			var frm = document.forms['reporter'];
			var field;
			<%
			if (reporterProperties != null)
			{
				for (ExtendedProperty ep : reporterProperties)
				{
					Type type = ep.getType();
					String name = ep.getName();
					%>
					field = frm['<%=name%>'];
					<%
					if (type == Type.DATE)
					{
						%>
						if (field.value != '' && !Dates.isDate(field.value, '<%=jsDateFormat%>'))
						{
							alert("'"+field.value+"' is not a valid date for '<%=HTML.javaScriptEncode(ep.getTitle())%>'");
							field.focus();
							return false;
						}
						<%
					}
					if (type == Type.TIMESTAMP)
					{
						%>
						if (field.value != '' && !Dates.isDate(field.value, '<%=jsDateTimeFormat%>'))
						{
							alert("'"+field.value+"' is not a valid timestamp for '<%=HTML.javaScriptEncode(ep.getTitle())%>'");
							field.focus();
							return false;
						}
						<%
					}
					if (!ep.isNullable())
					{
						if (type == Type.BOOLEAN)
						{
							%>
							if (Forms.getCheckedRadio(field) == null)
							{
								alert("You must select a value for '<%=HTML.javaScriptEncode(ep.getTitle())%>'");
								field.focus();
								return false;
							}
							<%
						}
						else
						{
							%>
							if (Main.trimString(field.value) == '')
							{
								alert("You must enter a value for '<%=HTML.javaScriptEncode(ep.getTitle())%>'.");
								field.focus();
								return false;
							}
							<%
						}
					}
				}
			}
			%>
			return true;
		}
		// Submit the form
		function saveSettings()
		{
			var frm = document.forms['reporter'];
			if (TabControl.validateActiveTab('settings'))
			{
				frm.submit();
			}
		}
		</script>
	</base:head>
	<base:body>
		<p>
		<form action="index.jsp?ID=<%=ID%>" method="post" name="reporter" onsubmit="return false;">
		<input type="hidden" name="cmd" value="UpdateItem">
		
		<h3 class="docked"><%=title%> <base:help tabcontrol="settings" /></h3>
		<t:tabcontrol id="settings" contentstyle="<%="height: "+(int)(scale*340)+"px;"%>" 
			position="bottom" remember="<%=reporter != null%>">
		<t:tab id="info" title="Reporter" validate="validateReporter()" helpid="reporter.edit">
			<table class="form" cellspacing=0>
			<tr>
				<td class="prompt">Name</td>
				<td><input <%=requiredClazz%> type="text" name="name" 
					value="<%=HTML.encodeTags(reporter == null ? Values.getString(cc.getPropertyValue("name"), "New reporter") : reporter.getName())%>" 
					size="40" maxlength="<%=ReporterData.MAX_NAME_LENGTH%>"></td>
			</tr>
			<tr>
				<td class="prompt">External ID</td>
				<td><input <%=requiredClazz%> type="text" name="externalId" 
					value="<%=HTML.encodeTags(reporter == null ? cc.getPropertyValue("externalId") : reporter.getExternalId())%>" 
					size="40" maxlength="<%=ReporterData.MAX_EXTERNAL_ID_LENGTH%>"></td>
			</tr>
			<tr>
				<td class="prompt">Type</td>
				<td>
					<select name="reportertype_id" <%=!readCurrentReporterType ? "disabled readonly class=\"disabled\"" : ""%>>
					<%
					if (!readCurrentReporterType)
					{
						%>
						<option value="-1">- denied -
						<%
					}
					else
					{
						%>
						<option value="0">- none -
						<%
						reporterTypes = reporterTypeQuery.iterate(dc);
						while (reporterTypes.hasNext())
						{
							ReporterType reporterType = reporterTypes.next();
							int rtId = reporterType.getId();
							%>
							<option
								value="<%=rtId == currentReporterTypeId && reporter != null ? -rtId : rtId %>"
								<%=rtId == currentReporterTypeId ? "selected" : "" %>
								><%=HTML.encodeTags(reporterType.getName())%>
							<%
						}
					}
					%>
					</select>
				</td>
			</tr>
			<tr>
				<td class="prompt">Gene symbol</td>
				<td><input <%=clazz%> type="text" name="symbol" 
					value="<%=HTML.encodeTags(reporter == null ? cc.getPropertyValue("symbol") : reporter.getSymbol())%>"
					size="40" maxlength="<%=ReporterData.MAX_SYMBOL_LENGTH%>"></td>
			</tr>
			<tr valign="top">
				<td class="prompt">Description</td>
				<td nowrap>
					<textarea <%=clazz%> rows="4" cols="40" name="description" wrap="virtual"
						><%=HTML.encodeTags(reporter == null ? cc.getPropertyValue("description") : reporter.getDescription())%></textarea>
					<a href="javascript:Main.zoom('Description', 'reporter', 'description')" title="Edit in larger window"><base:icon image="zoom.gif" /></a>
				</td>
			</tr>
			</table>
			<div align=right>&nbsp;<i><base:icon image="required.gif" /> = required information</i></div>
		</t:tab>
		
		<t:tab id="extended" title="Extended properties" 
			validate="validateExtendedProperties()" helpid="reporter.edit.extended">
			<table class="form" cellspacing=0>
				<%
				if (reporterProperties != null)
				{
					for (ExtendedProperty ep : ExtendedProperties.getProperties("ReporterData"))
					{
						String name = ep.getName();
						Type type = ep.getType();
						boolean required = !ep.isNullable();
						Object value = reporter == null ? cc.getPropertyValue(name) : reporter.getExtended(name);
						String theClazz = required ? requiredClazz : clazz;
						%>
						<tr valign="top">
							<td class="prompt"><%=HTML.encodeTags(ep.getTitle())%></td>
							<td>
							<%
							if (type == Type.INT || type == Type.LONG)
							{
								%>
								<input <%=theClazz%> type="text" name="<%=name%>" 
									value="<%=value == null ? "" : value%>"
									size="20" maxlength="20" onkeypress="return Numbers.integerOnly(event)"
									>
								<%
							}
							else if (type == Type.FLOAT || type == Type.DOUBLE)
							{
								%>
								<input <%=theClazz%> type="text" name="<%=name%>"
									value="<%=value == null ? "" : value%>"
									size="20" maxlength="20" onkeypress="return Numbers.numberOnly(event)"
									>
								<%
							}
							else if (type == Type.STRING)
							{
								%>
								<input <%=theClazz%> type="text" name="<%=name%>"
									value="<%=HTML.encodeTags((String)value)%>"
									size="40" maxlength="<%=ep.getLength()%>"
									>
								<%
							}
							else if (type == Type.TEXT)
							{
								%>
								<textarea <%=theClazz%> name="<%=name%>" rows="6" cols="40"
									><%=HTML.encodeTags((String)value)%></textarea>
								<a href="javascript:Main.zoom(
									'<%=HTML.javaScriptEncode(ep.getTitle())%>', 
									'reporter', '<%=name%>')" 
									title="Edit in larger window"><base:icon image="zoom.gif" /></a>
								<%
							}
							else if (type == Type.BOOLEAN)
							{
								Boolean b = (Boolean)value;
								if (!required)
								{
									%>
									<input type="radio" name="<%=name%>" value=""
										<%=b == null ? "checked" : ""%> 
										><i>- not specified -</i><br>
									<%
								}
								%>
								<input type="radio" name="<%=name%>" value="true" 
									<%=b != null && b == true ? "checked" : ""%>
									>true<br>
								<input type="radio" name="<%=name%>" value="false" 
									<%=b != null && b == false ? "checked" : ""%>
									>false
								<%
							}
							else if (type == Type.DATE)
							{
								%>
								<table>
								<tr>
								<td>
									<input <%=theClazz%> type="text" name="<%=name%>" 
										value="<%=dateFormatter.format((Date)value)%>"
										size="20" maxlength="20" title="Enter date in format: <%=htmlDateFormat%>"
										>
								</td>
								<td>
									<base:button 
										onclick="<%="Dates.selectDate('"+HTML.javaScriptEncode(ep.getTitle())+"', 'reporter', '"+name+"', null, '"+jsDateFormat +"')"%>" 
										image="calendar.png"
										title="Calendar&hellip;" 
										tooltip="Select a date from a calendar" 
									/>
								</td>
								</tr>
								</table>
								<%
							}
							else if (type == Type.TIMESTAMP)
							{
								%>
								<table>
								<tr>
								<td>
									<input <%=theClazz%> type="text" name="<%=name%>" 
										value="<%=dateTimeFormatter.format((Date)value)%>"
										size="20" maxlength="20" title="Enter timestamp in format: <%=htmlDateTimeFormat%>"
										>
								</td>
								<td>
									<base:button 
										onclick="<%="Dates.selectDateTime('"+HTML.javaScriptEncode(ep.getTitle())+"', 'reporter', '"+name+"', null, '"+jsDateTimeFormat +"')"%>" 
										image="calendar.png"
										title="Calendar&hellip;" 
										tooltip="Select a timestamp from a calendar" 
									/>
								</td>
								</tr>
								</table>
								<%
							}
							%>
							</td>
						</tr>
						<%
					}
				}
				%>
			</table>
		</t:tab>
		</t:tabcontrol>
		</form>

		<table align="center">
		<tr>
			<td width="50%"><base:button onclick="saveSettings()" title="Save" /></td>
			<td width="50%"><base:button onclick="window.close()" title="Cancel" /></td>
		</tr>
		</table>

	</base:body>
	</base:page>
	<%
}
finally
{
	if (reporterTypes != null) reporterTypes.close();
	if (dc != null) dc.close();
}

%>
